@@ -31,7 +31,7 @@ data T =
      deriving (Show, Eq, Ord)
 
 
-get :: Parser.C parser => Int -> Parser.Fallible parser T
+get :: Parser.C parser => Int -> Parser.Fragile parser T
 get tag =
    case tag of
       0xF0 -> liftM Regular $ getBigN =<< getVar
