@@ -11,8 +11,9 @@ import           Sound.MIDI.Message.Channel (Channel, toChannel, )
 import           Data.Ix(Ix)
 import qualified Data.List as List
 
-import Sound.MIDI.Utility (mapSnd,
-          enumRandomR, boundedEnumRandom, chooseEnum, )
+import Sound.MIDI.Utility
+          (enumRandomR, boundedEnumRandom, chooseEnum, )
+import Data.Tuple.HT (mapSnd, )
 import Test.QuickCheck (Arbitrary(arbitrary), )
 import System.Random (Random(random,randomR), )
 
