@@ -38,7 +38,7 @@ data T =
 --     deriving (Show)
 
 
-get :: Parser.C parser => Parser.Fallible parser T
+get :: Parser.C parser => Parser.Fragile parser T
 get =
    get1 >>= \code ->
    if code >= 0xF0
@@ -46,7 +46,7 @@ get =
      else liftM Channel $ (uncurry Channel.get (Channel.decodeStatus code) =<< get1)
 --     else liftM Channel $ StatusParser.run (Channel.getWithStatus code)
 
-getWithStatus :: Parser.C parser => Parser.Fallible (StatusParser.T parser) T
+getWithStatus :: Parser.C parser => Parser.Fragile (StatusParser.T parser) T
 getWithStatus =
    StatusParser.lift get1 >>= \code ->
    if code >= 0xF0
@@ -55,7 +55,7 @@ getWithStatus =
      else liftM Channel $ Channel.getWithStatus code
 
 getIncompleteWithStatus ::
-   Parser.C parser => Parser.Partial (Parser.Fallible (StatusParser.T parser)) T
+   Parser.C parser => Parser.Partial (Parser.Fragile (StatusParser.T parser)) T
 getIncompleteWithStatus =
    StatusParser.lift get1 >>= \code ->
    if code >= 0xF0
