@@ -30,10 +30,9 @@ import qualified Sound.MIDI.Bit as Bit
 
 import Sound.MIDI.Monoid ((+#+))
 
-import Sound.MIDI.Utility ({-checkRange,-} mapSnd, )
--- import Data.Ix (Ix)
+import Data.Tuple.HT (mapSnd, )
 
-import Test.QuickCheck (Arbitrary(arbitrary), )
+import Test.QuickCheck (Arbitrary(arbitrary, shrink), )
 import qualified Test.QuickCheck as QC
 
 
@@ -62,6 +61,13 @@ instance Arbitrary T where
             (20, liftM Voice arbitrary) :
             ( 1, liftM Mode  arbitrary) :
             [])
+   shrink (Cons chan body) =
+      map (\(c, b) -> Cons (toChannel (mod c 16)) b) $
+      case fromChannel chan of
+         c ->
+            case body of
+               Voice v -> map (mapSnd Voice) $ shrink (c, v)
+               Mode  m -> map (mapSnd Mode)  $ shrink (c, m)
 
 
 -- * serialization
@@ -75,7 +81,7 @@ we find out the status from the parser
 (it's been nice enough to keep track of it for us),
 and the tag that we've already gotten is the first byte of data.
 -}
-getWithStatus :: Parser.C parser => Int -> Parser.Fallible (StatusParser.T parser) T
+getWithStatus :: Parser.C parser => Int -> Parser.Fragile (StatusParser.T parser) T
 getWithStatus tag =
    do (status@(code, channel), firstData) <-
          if tag < 0x80
@@ -98,7 +104,7 @@ Note that since getting the first byte is a little complex
 the code, channel and first data byte
 must be determined by the caller.
 -}
-get :: Parser.C parser => Int -> Channel -> Int -> Parser.Fallible parser T
+get :: Parser.C parser => Int -> Channel -> Int -> Parser.Fragile parser T
 get code channel firstData =
    liftM (Cons channel) $
    if code == 11 && firstData >= 0x78
