@@ -13,7 +13,7 @@ import qualified Sound.MIDI.Writer.Basic as Writer
 import Sound.MIDI.Parser.Report (UserMessage, )
 
 import qualified Control.Monad.Exception.Asynchronous as Async
-import Sound.MIDI.Utility (toMaybe, )
+import Data.Maybe.HT (toMaybe, )
 import Control.Monad.Trans.Class (lift, )
 import Control.Monad (liftM, )
 
@@ -47,7 +47,7 @@ instance Arbitrary T where
 
 -- * serialization
 
-get :: Parser.C parser => Int -> Parser.Fallible parser T
+get :: Parser.C parser => Int -> Parser.Fragile parser T
 get mode =
    do x <- get1
       lift $ Parser.warnIncomplete $ uncurry Async.Exceptional $ fromControllerValue (mode,x)
