@@ -1,5 +1,7 @@
 module Sound.MIDI.Message.Class.Check where
 
+import qualified Sound.MIDI.Message.Class.Utility as CU
+
 import Sound.MIDI.Message.Channel (Channel, )
 import Sound.MIDI.Message.Channel.Voice (Pitch, Velocity, Program, Controller, )
 
@@ -21,6 +23,12 @@ for every type of event
 and make 'C' a subclass of all of them.
 -}
 class C event where
+   {- |
+   Warning: This returns note events as they are,
+   that is, a @NoteOff p 64@ might be encoded as such or as @NoteOn p 0@
+   depending on the content of @event@.
+   For normalized results you may use 'noteExplicitOff'.
+   -}
    note :: Channel -> event -> Maybe (Velocity, Pitch, Bool)
    program :: Channel -> event -> Maybe Program
    anyController :: Channel -> event -> Maybe (Controller, Int)
@@ -36,6 +44,27 @@ class C event where
    mode _chan _ev = Nothing
 
 
+{- |
+Like 'note', but converts @NoteOn p 0@ to @NoteOff p 64@.
+See 'VoiceMsg.explicitNoteOff'.
+-}
+noteExplicitOff ::
+   (C event) =>
+   Channel -> event -> Maybe (Velocity, Pitch, Bool)
+noteExplicitOff chan e =
+   fmap CU.explicitNoteOff $ note chan e
+
+{- |
+Like 'note', but converts @NoteOff p 64@ to @NoteOn p 0@.
+See 'VoiceMsg.implicitNoteOff'.
+-}
+noteImplicitOff ::
+   (C event) =>
+   Channel -> event -> Maybe (Velocity, Pitch, Bool)
+noteImplicitOff chan e =
+   fmap CU.implicitNoteOff $ note chan e
+
+
 controller ::
    (C event) =>
    Channel -> Controller -> event -> Maybe Int
