@@ -4,7 +4,7 @@ We need this for parsing MIDI tracks and some MetaEvents,
 where the length of a part is fixed by a length specification.
 -}
 module Sound.MIDI.Parser.Restricted
-   (T(..), run, runFallible, ) where
+   (T(..), run, runFragile, ) where
 
 import qualified Sound.MIDI.Parser.Class as Parser
 
@@ -12,6 +12,7 @@ import qualified Control.Monad.Exception.Synchronous  as Sync
 import qualified Control.Monad.Trans.Class as Trans
 import Control.Monad.Trans.State (StateT(runStateT), gets, get, put, )
 import Control.Monad (when, )
+import Control.Applicative (Applicative, pure, (<*>), )
 
 import qualified Numeric.NonNegative.Wrapper as NonNeg
 
@@ -27,12 +28,12 @@ run maxLen p =
          ("unparsed bytes left in part (" ++ show remaining ++ " bytes)")
       return x
 
-runFallible :: Parser.C parser =>
-   NonNeg.Integer -> Parser.Fallible (T parser) a -> Parser.Fallible parser a
-runFallible len = Sync.mapExceptionalT (run len)
+runFragile :: Parser.C parser =>
+   NonNeg.Integer -> Parser.Fragile (T parser) a -> Parser.Fragile parser a
+runFragile len = Sync.mapExceptionalT (run len)
 
 
-lift :: Monad parser => Parser.Fallible parser a -> Parser.Fallible (T parser) a
+lift :: Monad parser => Parser.Fragile parser a -> Parser.Fragile (T parser) a
 lift = Sync.mapExceptionalT Trans.lift
 
 
@@ -40,6 +41,13 @@ lift = Sync.mapExceptionalT Trans.lift
 newtype T parser a =
    Cons {decons :: StateT NonNeg.Integer parser a}
 
+instance Functor parser => Functor (T parser) where
+   fmap f = Cons . fmap f . decons
+
+instance (Applicative parser, Monad parser) => Applicative (T parser) where
+   pure = Cons . pure
+   Cons f <*> Cons a = Cons $ f <*> a
+
 instance Monad parser => Monad (T parser) where
    return = Cons . return
    x >>= y = Cons $ decons . y =<< decons x
@@ -48,10 +56,10 @@ instance Trans.MonadTrans T where
    lift = Cons . Trans.lift
 
 
-getRemaining :: Monad parser => Parser.Fallible (T parser) NonNeg.Integer
+getRemaining :: Monad parser => Parser.Fragile (T parser) NonNeg.Integer
 getRemaining = Trans.lift $ Cons get
 
-putRemaining :: Monad parser => NonNeg.Integer -> Parser.Fallible (T parser) ()
+putRemaining :: Monad parser => NonNeg.Integer -> Parser.Fragile (T parser) ()
 putRemaining = Trans.lift . Cons . put
 
 
